# typically

Types, data(types), and utilities (for types) that are *typically* used at some point in most of the projects I work on.

The goal is to minimize the number of required dependencies, reimplementing permissively licensed code in this project if required. Currently, the dependencies are:

- [pydantic](https://github.com/pydantic/pydantic)
- [orjson](https://github.com/ijl/orjson)

<!--
Maybe will add, but probably split into separate project:

- [cryptography](https://github.com/pyca/cryptography)
- [scipy](https://github.com/scipy/scipy)
- [sympy](https://github.com/sympy/sympy)
- [numpy](https://github.com/numpy/numpy)

## References

- [superstring]()
- [adict]()

-->
Ö